function [D2Phi1,D2Phi2] = D2phi(theta,z)
%%% Function for making Phi''(theta) (Phi-double-prime)
% Input "theta" is vector interval for pitch motion or single value.
% Input "z" is vector of control-points for the virtual holonomic
% constraints.

global theta_b theta_e coeff_degree

a = z(1:coeff_degree+1);
b = z(coeff_degree+2:end);

x = theta;
xb = theta_b;
xe = theta_e;

switch coeff_degree
    case 4
        D2Phi1 = ((4.*a(1)-16.*a(2)+24.*a(3)-16.*a(4)+4.*a(5)).*x.^3+((12.*a(2)-36.*a(3)+36.*a(4)-12.*a(5)).*xb-12.*xe.*(a(1)-3.*a(2)+3.*a(3)-a(4))).*x.^2+((12.*a(3)-24.*a(4)+12.*a(5)).*xb.^2-24.*xe.*(a(2)-2.*a(3)+a(4)).*xb+12.*xe.^2.*(a(1)-2.*a(2)+a(3))).*x+(4.*a(4)-4.*a(5)).*xb.^3-12.*xe.*(a(3)-a(4)).*xb.^2+12.*xe.^2.*(a(2)-a(3)).*xb-4.*xe.^3.*(a(1)-a(2)))./(-xe+xb).^4;
        D2Phi2 = ((4.*b(1)-16.*b(2)+24.*b(3)-16.*b(4)+4.*b(5)).*x.^3+((12.*b(2)-36.*b(3)+36.*b(4)-12.*b(5)).*xb-12.*xe.*(b(1)-3.*b(2)+3.*b(3)-b(4))).*x.^2+((12.*b(3)-24.*b(4)+12.*b(5)).*xb.^2-24.*xe.*(b(2)-2.*b(3)+b(4)).*xb+12.*xe.^2.*(b(1)-2.*b(2)+b(3))).*x+(4.*b(4)-4.*b(5)).*xb.^3-12.*xe.*(b(3)-b(4)).*xb.^2+12.*xe.^2.*(b(2)-b(3)).*xb-4.*xe.^3.*(b(1)-b(2)))./(-xe+xb).^4;
    case 5
        D2Phi1 = ((5.*a(1)-25.*a(2)+50.*a(3)-50.*a(4)+25.*a(5)-5.*a(6)).*x.^4+((20.*a(2)-80.*a(3)+120.*a(4)-80.*a(5)+20.*a(6)).*xb-20.*xe.*(a(1)-4.*a(2)+6.*a(3)-4.*a(4)+a(5))).*x.^3+((30.*a(3)-90.*a(4)+90.*a(5)-30.*a(6)).*xb.^2-60.*xe.*(a(2)-3.*a(3)+3.*a(4)-a(5)).*xb+30.*xe.^2.*(a(1)-3.*a(2)+3.*a(3)-a(4))).*x.^2+((20.*a(4)-40.*a(5)+20.*a(6)).*xb.^3-60.*xe.*(a(3)-2.*a(4)+a(5)).*xb.^2+60.*xe.^2.*(a(2)-2.*a(3)+a(4)).*xb-20.*xe.^3.*(a(1)-2.*a(2)+a(3))).*x+(5.*a(5)-5.*a(6)).*xb.^4-20.*xe.*(a(4)-a(5)).*xb.^3+30.*xe.^2.*(a(3)-a(4)).*xb.^2-20.*xe.^3.*(a(2)-a(3)).*xb+5.*xe.^4.*(a(1)-a(2)))./(-xe+xb).^5;
        D2Phi2 = ((5.*b(1)-25.*b(2)+50.*b(3)-50.*b(4)+25.*b(5)-5.*b(6)).*x.^4+((20.*b(2)-80.*b(3)+120.*b(4)-80.*b(5)+20.*b(6)).*xb-20.*xe.*(b(1)-4.*b(2)+6.*b(3)-4.*b(4)+b(5))).*x.^3+((30.*b(3)-90.*b(4)+90.*b(5)-30.*b(6)).*xb.^2-60.*xe.*(b(2)-3.*b(3)+3.*b(4)-b(5)).*xb+30.*xe.^2.*(b(1)-3.*b(2)+3.*b(3)-b(4))).*x.^2+((20.*b(4)-40.*b(5)+20.*b(6)).*xb.^3-60.*xe.*(b(3)-2.*b(4)+b(5)).*xb.^2+60.*xe.^2.*(b(2)-2.*b(3)+b(4)).*xb-20.*xe.^3.*(b(1)-2.*b(2)+b(3))).*x+(5.*b(5)-5.*b(6)).*xb.^4-20.*xe.*(b(4)-b(5)).*xb.^3+30.*xe.^2.*(b(3)-b(4)).*xb.^2-20.*xe.^3.*(b(2)-b(3)).*xb+5.*xe.^4.*(b(1)-b(2)))./(-xe+xb).^5;
    case 6
        D2Phi1 = ((6.*a(7)+6.*a(1)-36.*a(2)+90.*a(3)-120.*a(4)+90.*a(5)-36.*a(6)).*x.^5+((-30.*a(7)+30.*a(2)-150.*a(3)+300.*a(4)-300.*a(5)+150.*a(6)).*xb-30.*xe.*(a(1)-5.*a(2)+10.*a(3)-10.*a(4)+5.*a(5)-a(6))).*x.^4+((60.*a(7)+60.*a(3)-240.*a(4)+360.*a(5)-240.*a(6)).*xb.^2-120.*xe.*(a(2)-4.*a(3)+6.*a(4)-4.*a(5)+a(6)).*xb+60.*xe.^2.*(a(1)-4.*a(2)+6.*a(3)-4.*a(4)+a(5))).*x.^3+((-60.*a(7)+60.*a(4)-180.*a(5)+180.*a(6)).*xb.^3-180.*xe.*(a(3)-3.*a(4)+3.*a(5)-a(6)).*xb.^2+180.*xe.^2.*(a(2)-3.*a(3)+3.*a(4)-a(5)).*xb-60.*xe.^3.*(a(1)-3.*a(2)+3.*a(3)-a(4))).*x.^2+((30.*a(7)+30.*a(5)-60.*a(6)).*xb.^4-120.*xe.*(a(4)-2.*a(5)+a(6)).*xb.^3+180.*xe.^2.*(a(3)-2.*a(4)+a(5)).*xb.^2-120.*xe.^3.*(a(2)-2.*a(3)+a(4)).*xb+30.*xe.^4.*(a(1)-2.*a(2)+a(3))).*x+(-6.*a(7)+6.*a(6)).*xb.^5-30.*xe.*(a(5)-a(6)).*xb.^4+60.*xe.^2.*(a(4)-a(5)).*xb.^3-60.*xe.^3.*(a(3)-a(4)).*xb.^2+30.*xe.^4.*(a(2)-a(3)).*xb-6.*xe.^5.*(a(1)-a(2)))./(-xe+xb).^6;
        D2Phi2 = ((6.*b(7)+6.*b(1)-36.*b(2)+90.*b(3)-120.*b(4)+90.*b(5)-36.*b(6)).*x.^5+((-30.*b(7)+30.*b(2)-150.*b(3)+300.*b(4)-300.*b(5)+150.*b(6)).*xb-30.*xe.*(b(1)-5.*b(2)+10.*b(3)-10.*b(4)+5.*b(5)-b(6))).*x.^4+((60.*b(7)+60.*b(3)-240.*b(4)+360.*b(5)-240.*b(6)).*xb.^2-120.*xe.*(b(2)-4.*b(3)+6.*b(4)-4.*b(5)+b(6)).*xb+60.*xe.^2.*(b(1)-4.*b(2)+6.*b(3)-4.*b(4)+b(5))).*x.^3+((-60.*b(7)+60.*b(4)-180.*b(5)+180.*b(6)).*xb.^3-180.*xe.*(b(3)-3.*b(4)+3.*b(5)-b(6)).*xb.^2+180.*xe.^2.*(b(2)-3.*b(3)+3.*b(4)-b(5)).*xb-60.*xe.^3.*(b(1)-3.*b(2)+3.*b(3)-b(4))).*x.^2+((30.*b(7)+30.*b(5)-60.*b(6)).*xb.^4-120.*xe.*(b(4)-2.*b(5)+b(6)).*xb.^3+180.*xe.^2.*(b(3)-2.*b(4)+b(5)).*xb.^2-120.*xe.^3.*(b(2)-2.*b(3)+b(4)).*xb+30.*xe.^4.*(b(1)-2.*b(2)+b(3))).*x+(-6.*b(7)+6.*b(6)).*xb.^5-30.*xe.*(b(5)-b(6)).*xb.^4+60.*xe.^2.*(b(4)-b(5)).*xb.^3-60.*xe.^3.*(b(3)-b(4)).*xb.^2+30.*xe.^4.*(b(2)-b(3)).*xb-6.*xe.^5.*(b(1)-b(2)))./(-xe+xb).^6;
    case 7
        D2Phi1 = 7.*a(1).*(-xe+x).^6./(-xe+xb).^7-7.*a(2).*(-xe+x).^6./(-xe+xb).^7-42.*a(2).*(x-xb).*(-xe+x).^5./(-xe+xb).^7+42.*a(3).*(x-xb).*(-xe+x).^5./(-xe+xb).^7+105.*a(3).*(x-xb).^2.*(-xe+x).^4./(-xe+xb).^7+105.*a(4).*(x-xb).^2.*(xe-x).^4./(xe-xb).^7-140.*a(4).*(x-xb).^3.*(xe-x).^3./(xe-xb).^7+140.*a(5).*(xb-x).^3.*(xe-x).^3./(-xe+xb).^7+105.*a(5).*(xb-x).^4.*(xe-x).^2./(-xe+xb).^7-105.*a(6).*(x-xb).^4.*(-xe+x).^2./(-xe+xb).^7-42.*a(6).*(x-xb).^5.*(-xe+x)./(-xe+xb).^7+42.*a(7).*(x-xb).^5.*(-xe+x)./(-xe+xb).^7-7.*a(7).*(x-xb).^6./(xe-xb).^7+7.*a(8).*(x-xb).^6./(xe-xb).^7;
        D2Phi2 = 7.*b(1).*(-xe+x).^6./(-xe+xb).^7-7.*b(2).*(-xe+x).^6./(-xe+xb).^7-42.*b(2).*(x-xb).*(-xe+x).^5./(-xe+xb).^7+42.*b(3).*(x-xb).*(-xe+x).^5./(-xe+xb).^7+105.*b(3).*(x-xb).^2.*(-xe+x).^4./(-xe+xb).^7+105.*b(4).*(x-xb).^2.*(xe-x).^4./(xe-xb).^7-140.*b(4).*(x-xb).^3.*(xe-x).^3./(xe-xb).^7+140.*b(5).*(xb-x).^3.*(xe-x).^3./(-xe+xb).^7+105.*b(5).*(xb-x).^4.*(xe-x).^2./(-xe+xb).^7-105.*b(6).*(x-xb).^4.*(-xe+x).^2./(-xe+xb).^7-42.*b(6).*(x-xb).^5.*(-xe+x)./(-xe+xb).^7+42.*b(7).*(x-xb).^5.*(-xe+x)./(-xe+xb).^7-7.*b(7).*(x-xb).^6./(xe-xb).^7+7.*b(8).*(x-xb).^6./(xe-xb).^7;
    case 8
        D2Phi1 = 8.*a(1).*(-xe+x).^7./(-xe+xb).^8-8.*a(2).*(-xe+x).^7./(-xe+xb).^8-56.*a(2).*(x-xb).*(-xe+x).^6./(-xe+xb).^8+56.*a(3).*(x-xb).*(-xe+x).^6./(-xe+xb).^8+168.*a(3).*(x-xb).^2.*(-xe+x).^5./(-xe+xb).^8+168.*a(4).*(x-xb).^2.*(xe-x).^5./(xe-xb).^8-280.*a(4).*(x-xb).^3.*(xe-x).^4./(xe-xb).^8-280.*a(5).*(xb-x).^3.*(xe-x).^4./(-xe+xb).^8-280.*a(5).*(xb-x).^4.*(xe-x).^3./(-xe+xb).^8-280.*a(6).*(x-xb).^4.*(-xe+x).^3./(-xe+xb).^8-168.*a(6).*(x-xb).^5.*(-xe+x).^2./(-xe+xb).^8+168.*a(7).*(x-xb).^5.*(-xe+x).^2./(-xe+xb).^8+56.*a(7).*(x-xb).^6.*(-xe+x)./(-xe+xb).^8-56.*a(8).*(x-xb).^6.*(-xe+x)./(-xe+xb).^8-8.*a(8).*(x-xb).^7./(xe-xb).^8+8.*a(9).*(x-xb).^7./(xe-xb).^8;
        D2Phi2 = 8.*b(1).*(-xe+x).^7./(-xe+xb).^8-8.*b(2).*(-xe+x).^7./(-xe+xb).^8-56.*b(2).*(x-xb).*(-xe+x).^6./(-xe+xb).^8+56.*b(3).*(x-xb).*(-xe+x).^6./(-xe+xb).^8+168.*b(3).*(x-xb).^2.*(-xe+x).^5./(-xe+xb).^8+168.*b(4).*(x-xb).^2.*(xe-x).^5./(xe-xb).^8-280.*b(4).*(x-xb).^3.*(xe-x).^4./(xe-xb).^8-280.*b(5).*(xb-x).^3.*(xe-x).^4./(-xe+xb).^8-280.*b(5).*(xb-x).^4.*(xe-x).^3./(-xe+xb).^8-280.*b(6).*(x-xb).^4.*(-xe+x).^3./(-xe+xb).^8-168.*b(6).*(x-xb).^5.*(-xe+x).^2./(-xe+xb).^8+168.*b(7).*(x-xb).^5.*(-xe+x).^2./(-xe+xb).^8+56.*b(7).*(x-xb).^6.*(-xe+x)./(-xe+xb).^8-56.*b(8).*(x-xb).^6.*(-xe+x)./(-xe+xb).^8-8.*b(8).*(x-xb).^7./(xe-xb).^8+8.*b(9).*(x-xb).^7./(xe-xb).^8;
end