function [c, ceq] = nonLinCon(q)
% Nonlinear constraints
% Can be used for finding feasible points, this can some times be quite
% difficult.

global theta_b theta_e samples coeff_degree
global psi l1 l2 l3 kspr

z = q(1:coeff_degree*2+2);
theta_b = q(end-3);
theta_e = q(end-2);
kspr = q(end-1);
psi = q(end);

theta = linspace(theta_b,theta_e,samples)';

[Phi1,Phi2] = phi(theta,z);
[DPhi1,DPhi2] = Dphi(theta,z);
q3 = acos((theta-l1*cos(Phi1-psi)-l2*cos(Phi1+Phi2-psi))./l3)-Phi1-Phi2+psi;

theta_dot_sqrd_vec = theta_dot_sqrd(z);
[Torque1,Torque2] = torque(theta,z,theta_dot_sqrd_vec);

% alpha3 are for finding feasible starting point. 
% First: find an alpha-vector strictly greater or smaller than 0.
% Second: Confirm theta_dot_sqrd >= 0. While this is not true, DPhi and
% Torque must be commented.

% This link explains how to run fmincon w.r.t constraints only:
% http://www.mathworks.se/help/optim/ug/when-the-solver-fails.html#br44i73

alpha3 = al3(theta,z);

% -30<=q1<=210 (in degrees)
c(1:length(theta)) = -Phi1-1/6*pi;
c(length(theta)+1:2*length(theta)) = Phi1-7/6*pi;

% -120<=q2<=120 (in degrees)
c(2*length(theta)+1:3*length(theta)) = abs(Phi2)-2/3*pi;

c(3*length(theta)+1:4*length(theta)) = abs(theta-l1*cos(Phi1-psi)-l2*cos(Phi1+Phi2-psi))-l3;

% -120<=q3<=120 (in degrees)
c(4*length(theta)+1:5*length(theta)) = abs(q3)-2/3*pi;

% DPhi*Dtheta (velocity constraints for q1, q2 and q3
c(5*length(theta)+1:6*length(theta)) = (DPhi1.*sqrt(theta_dot_sqrd_vec))-11/18*pi;
c(6*length(theta)+1:7*length(theta)) = -(DPhi1.*sqrt(theta_dot_sqrd_vec))-11/18*pi;
c(7*length(theta)+1:8*length(theta)) = (DPhi2.*sqrt(theta_dot_sqrd_vec))-32/45*pi;
c(8*length(theta)+1:9*length(theta)) = -(DPhi2.*sqrt(theta_dot_sqrd_vec))-32/45*pi;
c(9*length(theta)+1:10*length(theta)) = ((-sqrt(theta_dot_sqrd_vec)-l1.*sin(Phi1-psi).*DPhi1.*sqrt(theta_dot_sqrd_vec)-l2.*sin(Phi1+Phi2-psi).*(DPhi1+DPhi2).*sqrt(theta_dot_sqrd_vec))./(l3.*sin(Phi1+Phi2+q3-psi))-DPhi1.*sqrt(theta_dot_sqrd_vec)-DPhi2.*sqrt(theta_dot_sqrd_vec))-46/45*pi;
c(10*length(theta)+1:11*length(theta)) = -((-sqrt(theta_dot_sqrd_vec)-l1.*sin(Phi1-psi).*DPhi1.*sqrt(theta_dot_sqrd_vec)-l2.*sin(Phi1+Phi2-psi).*(DPhi1+DPhi2).*sqrt(theta_dot_sqrd_vec))./(l3.*sin(Phi1+Phi2+q3-psi))-DPhi1.*sqrt(theta_dot_sqrd_vec)-DPhi2.*sqrt(theta_dot_sqrd_vec))-46/45*pi;

% Constraints for Torque 1 and 2
c(11*length(theta)+1:12*length(theta)) = abs(Torque1)-176;
c(12*length(theta)+1:13*length(theta)) = abs(Torque2)-100;

% Only one of these must be used. Plot alpha first.
% c(13*length(theta)+1:14*length(theta)) = -alpha3+0.0001;
c(13*length(theta)+1:14*length(theta)) = alpha3+0.0001;

c(14*length(theta)+1:15*length(theta)-1) = -theta_dot_sqrd_vec(2:end);

ceq = [];

end

