function [distance_thrown,c,ceq] = obj_func_nonLinCon(q)
% Objective-function and nonlinear constraints used in the nested
% optimization function.
% Input "q" is the scalar parameter vector to be used in the search.
% If start-point is infeasible, check nonLinCon.m

global theta_b theta_e samples coeff_degree
global psi l0 l1 l2 l3 kspr g z

z = q(1:coeff_degree*2+2);
theta_b = q(end-3);
theta_e = q(end-2);
kspr = q(end-1);
psi = q(end);

theta_interval = linspace(theta_b,theta_e,samples)';

y1 = zeros(length(theta_interval),1);
y2 = zeros(length(theta_interval),1);

for i = 2:length(theta_interval)
    y1(i) = y1(i-1) + integral(@(theta)be3(theta,z)./al3(theta,z),theta_interval(i-1),theta_interval(i));
end
y1 = exp(-2*y1);

for i = 2:length(theta_interval)
    y2(i) = y2(i-1)+2*integral(@(theta)interp1(theta_interval,y1,theta,'spline').\gam3(theta,z)./al3(theta,z),theta_interval(i-1),theta_interval(i));
end
theta_dot_sqrd_vec = -y1.*y2;

[Phi1,Phi2] = phi(theta_interval,z);
[DPhi1,DPhi2] = Dphi(theta_interval,z);
q3 = acos((theta_interval-l1*cos(Phi1-psi)-l2*cos(Phi1+Phi2-psi))./l3)-Phi1-Phi2+psi;
[Torque1,Torque2] = torque(theta_interval,z,theta_dot_sqrd_vec);
alpha3 = al3(theta_interval,z);


x_e = l1*cos(Phi1(end))+l2*cos(Phi1(end)+Phi2(end))+l3*cos(Phi1(end)+Phi2(end)+q3(end));
y_e = l0+l1*sin(Phi1(end))+l2*sin(Phi1(end)+Phi2(end))+l3*sin(Phi1(end)+Phi2(end)+q3(end));

x_vel = sqrt(theta_dot_sqrd_vec(end))*cos(psi);
y_vel = sqrt(theta_dot_sqrd_vec(end))*sin(psi);

distance_thrown = x_vel*y_vel/g+sqrt((x_vel*y_vel/g)^2+2*x_vel^2*y_e/g)+x_e;

% -30<=q1<=210 (in degrees)
c(1:length(theta_interval)) = -Phi1-1/6*pi;
c(length(theta_interval)+1:2*length(theta_interval)) = Phi1-7/6*pi;

% -120<=q2<=120 (in degrees)
c(2*length(theta_interval)+1:3*length(theta_interval)) = abs(Phi2)-2/3*pi;

c(3*length(theta_interval)+1:4*length(theta_interval)) = abs(theta_interval-l1*cos(Phi1-psi)-l2*cos(Phi1+Phi2-psi))-l3;

% -120<=q3<=120 (in degrees)
c(4*length(theta_interval)+1:5*length(theta_interval)) = abs(q3)-2/3*pi;

% DPhi*Dtheta (velocity constraints for q1, q2 and q3 (without load))
c(5*length(theta_interval)+1:6*length(theta_interval)) = (DPhi1.*sqrt(theta_dot_sqrd_vec))-11/18*pi;
c(6*length(theta_interval)+1:7*length(theta_interval)) = -(DPhi1.*sqrt(theta_dot_sqrd_vec))-11/18*pi;
c(7*length(theta_interval)+1:8*length(theta_interval)) = (DPhi2.*sqrt(theta_dot_sqrd_vec))-32/45*pi;
c(8*length(theta_interval)+1:9*length(theta_interval)) = -(DPhi2.*sqrt(theta_dot_sqrd_vec))-32/45*pi;
c(9*length(theta_interval)+1:10*length(theta_interval)) = ((-sqrt(theta_dot_sqrd_vec)-l1.*sin(Phi1-psi).*DPhi1.*sqrt(theta_dot_sqrd_vec)-l2.*sin(Phi1+Phi2-psi).*(DPhi1+DPhi2).*sqrt(theta_dot_sqrd_vec))./(l3.*sin(Phi1+Phi2+q3-psi))-DPhi1.*sqrt(theta_dot_sqrd_vec)-DPhi2.*sqrt(theta_dot_sqrd_vec))-46/45*pi;
c(10*length(theta_interval)+1:11*length(theta_interval)) = -((-sqrt(theta_dot_sqrd_vec)-l1.*sin(Phi1-psi).*DPhi1.*sqrt(theta_dot_sqrd_vec)-l2.*sin(Phi1+Phi2-psi).*(DPhi1+DPhi2).*sqrt(theta_dot_sqrd_vec))./(l3.*sin(Phi1+Phi2+q3-psi))-DPhi1.*sqrt(theta_dot_sqrd_vec)-DPhi2.*sqrt(theta_dot_sqrd_vec))-46/45*pi;

% Constraints for Torque 1 and 2
c(11*length(theta_interval)+1:12*length(theta_interval)) = abs(Torque1)-176;
c(12*length(theta_interval)+1:13*length(theta_interval)) = abs(Torque2)-100;

% c(13*length(theta_interval)+1:14*length(theta_interval)) = -alpha3+0.00001;
c(13*length(theta_interval)+1:14*length(theta_interval)) = alpha3+0.00001;

c(14*length(theta_interval)+1:15*length(theta_interval)-1) = -theta_dot_sqrd_vec(2:end);

ceq = [];

end